==> bookmarkbridge_0.72.orig.tar.gz: bookmarkbridge-0.72/bookmarkbridge/dlgabout.cpp <==
/***************************************************************************
                          dlgabout.cpp  -  description
                             -------------------
    begin                : Sun Dec 29 2002
    copyright            : (C) 2002 by Ken Schenke
    email                : kenschenke at yahoo dot com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   In addition, as a special exception, Ken Schenke gives permission to  *
 *   link the code of this program with the Qt non-commercial edition (or  *
 *   with modified versions of the Qt non-commercial edition that use the  *
 *   same license as the Qt non-commercial edition, and distribute linked  *
 *   combinations including the two.  You must obey the GNU General Public *
 *   License in all respects for all of the code used other than the Qt    *
 *   Non-Commercial edition.  If you modify this file, you may extend this *
 *   exception to your version of the file, but you are not obligated to   *
 *   do so.  If you do not wish to do so, delete this exception statement  *
 *   from your version.                                                    *
 *                                                                         *
 ***************************************************************************/

#include "dlgabout.h"
#include "version.h"

#ifdef Q_WS_X11
#include "config.h"
#endif

#include <qtextbrowser.h>
#include <qstring.h>

static const char *about_text =
	"<html><head><title>About BookmarkBridge</title></head><body bgcolor=\"#FFFFFF\">"
	"<center>"
	"<img src=\"bookmarkbridgelogo\" border=\"0\" width=\"248\" height=\"71\"><br>"
	"<h3 style=\"text-align:center\">"
	"Version " BMB_VERSION "<br>"
	"http://bookmarkbridge.sourceforge.net<br>"
	"Copyright 2003-2004 by Ken Schenke "
	"kschenke@users.sourceforge.net"
	"</h3>"
	"</center>"
	"<table border=\"0\">"
	"<tr>"
	"<td valign=\"center\">"
	"<img src=\"osilogo\" border=\"0\" width=\"72\" height=\"60\">"
	"</td>"
	"<td align=\"left\"><font size=\"-1\">"
	"This program is free software; you can redistribute it and/or modify "
	"it under the terms of the GNU General Public License as published by "
	"the Free Software Foundation; either version 2 of the License, or "
	"(at your option) any later version."
	"</td></tr></table>"
	"<center><font size=\"-1\">"
	"This software is OSI Certified Open Source Software. "
	"OSI Certified is a certification mark of the Open Source Initiative."
	"<br>http://www.opensource.org"
	"</font></center>"
	"</body></html>";

/***************************************************************************
 *                                                                         *
 *   DlgAbout::DlgAbout()                                                  *
 *                                                                         *
 *   Parameters:                                                           *
 *      const BridgeCfg &cfg                                               *
 *      QWidget *parent                                                    *
 *      const char *name                                                   *
 *      bool modal                                                         *
 *      WFlags f                                                           *
 *   Return:                                                               *
 *      None                                                               *
 *   Description:                                                          *
 *      Class constructor                                                  *
 *                                                                         *
 ***************************************************************************/

DlgAbout::DlgAbout(
	QWidget *parent,
	const char *name,
	bool modal,
	WFlags f)
	: DlgAboutBase(parent, name, modal, f)
{
	browser->setText(about_text);
}

==> bookmarkbridge_0.76.orig.tar.gz: bookmarkbridge-0.76/bookmarkbridge/dlgabout.cpp <==
/***************************************************************************
                          dlgabout.cpp  -  description
                             -------------------
    begin                : Sun Dec 29 2002
    copyright            : (C) 2002 by Ken Schenke
    email                : kschenke at users dot sourceforge dot net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful, but   *
 *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
 *   General Public License for more details.                              *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the Free Software           *
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA         *
 *   02110-1301, USA                                                       *
 *                                                                         *
 ***************************************************************************/

#include "dlgabout.h"
#include "version.h"

static const char *about_text =
	"<html><head><title>About BookmarkBridge</title></head><body bgcolor=\"#FFFFFF\">"
	"<center>"
	"<img src=\":bookmarkbridgelogo.png\" border=\"0\" width=\"186\" height=\"53\"><br>"
	"<h3 style=\"text-align:center\">"
	"Version " BMB_VERSION "<br>"
	"http://www.bookmarkbridge.org<br>"
	"Copyright 2003-2005 by Ken Schenke "
	"kschenke@users.sourceforge.net"
	"</h3>"
	"</center>"
	"<table border=\"0\">"
	"<tr>"
	"<td valign=\"center\">"
	"<img src=\":osi-certified-72x60.png\" border=\"0\" width=\"72\" height=\"60\">"
	"</td>"
	"<td align=\"left\"><font size=\"-1\">"
	"This program is free software; you can redistribute it and/or modify "
	"it under the terms of the GNU General Public License as published by "
	"the Free Software Foundation; either version 2 of the License, or "
	"(at your option) any later version."
	"</td></tr></table>"
	"<center><font size=\"-1\">"
	"This software is OSI Certified Open Source Software. "
	"OSI Certified is a certification mark of the Open Source Initiative."
	"<br>http://www.opensource.org"
	"</font></center>"
	"</body></html>";

/***************************************************************************
 *                                                                         *
 *   DlgAbout::DlgAbout()                                                  *
 *                                                                         *
 *   Parameters:                                                           *
 *      QWidget *parent                                                    *
 *   Return:                                                               *
 *      None                                                               *
 *   Description:                                                          *
 *      Class constructor                                                  *
 *                                                                         *
 ***************************************************************************/

DlgAbout::DlgAbout(QWidget *parent)
	: QDialog(parent)
{
	setupUi(this);
	browser->setHtml(about_text);
}
